@@ -42,17 +42,17 @@ signal_filter (DBusConnection *connection, DBusMessage *message, void *user_data
   /* User data is the event loop we are running in */
   appdata_t *appdata = (appdata_t*)user_data;
 
-  printf("got a dbus message from Maemo Mapper\n");
-
-  if(dbus_message_is_signal(message, MM_DBUS_SERVICE, "view_position_changed")) {
+  if(dbus_message_is_signal(message, MM_DBUS_SERVICE, 
+			    "view_position_changed")) {
     DBusError error;
     double lat, lon;
     dbus_error_init (&error);
   
-    printf("  is \"view position changed\"\n");
+    printf("Received \"view position changed\"\n");
     
     if(dbus_message_get_args
-       (message, &error, DBUS_TYPE_DOUBLE, &lat, DBUS_TYPE_DOUBLE, &lon, DBUS_TYPE_INVALID)) {
+       (message, &error, DBUS_TYPE_DOUBLE, &lat, 
+	DBUS_TYPE_DOUBLE, &lon, DBUS_TYPE_INVALID)) {
 
       g_print("  Position received: %f/%f\n", (float)lat, (float)lon);
 
