@@ -23,7 +23,10 @@
 typedef struct {
   appdata_t *appdata;
   GtkTextBuffer *buffer;
-  GtkWidget *entry, *label_sum, *menu;
+  GtkWidget *entry, *label_sum;
+#ifndef NO_COPY_N_PASTE
+  GtkWidget *menu;
+#endif
 } geotext_context_t;
 
 /* buffer edited */
@@ -95,6 +98,7 @@ static void on_right_shift_clicked(GtkButton *button, gpointer data) {
   text_shift((geotext_context_t*)data, +1);
 }
 
+#ifndef NO_COPY_N_PASTE
 static void 
 cb_cut(GtkWidget *widget, gpointer data) {
   geotext_context_t *context = (geotext_context_t*)data;
@@ -150,6 +154,7 @@ static gint button_press(GtkWidget *widget, GdkEventButton *event,
   /* Tell calling code that we have not handled this event; pass it on. */
   return FALSE;
 }
+#endif
 
 void geotext_dialog(appdata_t *appdata) {
   geotext_context_t context;
@@ -176,12 +181,14 @@ void geotext_dialog(appdata_t *appdata) {
   gtk_misc_set_alignment(GTK_MISC(label), 0.f, 0.5f);
   gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
 
+#ifndef NO_COPY_N_PASTE
   GtkWidget *but = gtk_button_new_with_label(_("Edit"));
   gtk_widget_set_events(but, GDK_EXPOSURE_MASK);
   gtk_widget_add_events(but, GDK_BUTTON_PRESS_MASK);
   gtk_signal_connect(GTK_OBJECT(but), "button-press-event",
 		     (GtkSignalFunc)button_press, &context);
   gtk_box_pack_start(GTK_BOX(hbox), but, FALSE, FALSE, 0);
+#endif
 
   gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), 
 		     hbox, FALSE, FALSE, 0);
@@ -202,7 +209,7 @@ void geotext_dialog(appdata_t *appdata) {
   if(appdata->geotext_text)
     gtk_text_buffer_set_text(context.buffer, appdata->geotext_text, -1);
 
-#ifndef USE_MAEMO
+#ifndef USE_HILDON_TEXT_VIEW
   GtkWidget *view = gtk_text_view_new_with_buffer(context.buffer);
 #else
   GtkWidget *view = hildon_text_view_new();
