@@ -641,7 +641,7 @@ GtkWidget *goto_cache(cache_context_t *context) {
   gtk_signal_connect(GTK_OBJECT(radio), "clicked",
 		     (GtkSignalFunc)radio_changed_event, context);
 
-  context->gotoc.edit_but = gtk_button_new_with_label(_("Edit..."));
+  context->gotoc.edit_but = gtk_button_new_with_label(_("Edit"));
   gtk_table_attach_defaults(GTK_TABLE(table), context->gotoc.edit_but, 1,2,1,2);
   gtk_signal_connect(GTK_OBJECT(context->gotoc.edit_but), "clicked",
 		     (GtkSignalFunc)on_posedit_clicked, context);
