@@ -155,7 +155,7 @@ gpx_dialog_t *gpx_busy_dialog_new(GtkWidget *parent) {
   gtk_window_set_title(GTK_WINDOW(dialog->dialog), _("Loading"));
   gtk_window_set_default_size(GTK_WINDOW(dialog->dialog), 300, 10);
 
-  gtk_window_set_modal(GTK_WINDOW(dialog), TRUE);
+  gtk_window_set_modal(GTK_WINDOW(dialog->dialog), TRUE);
   gtk_window_set_transient_for(GTK_WINDOW(dialog->dialog), GTK_WINDOW(parent));
 
   dialog->label = gtk_label_new("---");
