@@ -468,12 +468,12 @@ static GtkWidget *location_widget(location_context_t *context) {
   /* ------- button box ------------ */
 
   GtkWidget *hbox = gtk_hbox_new(TRUE,3);
-  context->but_add = gtk_button_new_with_label(_("Add..."));
+  context->but_add = gtk_button_new_with_label(_("Add"));
   gtk_box_pack_start_defaults(GTK_BOX(hbox), context->but_add);
   gtk_signal_connect(GTK_OBJECT(context->but_add), "clicked",
 		     GTK_SIGNAL_FUNC(on_location_add), context);
 
-  context->but_edit = gtk_button_new_with_label(_("Edit..."));
+  context->but_edit = gtk_button_new_with_label(_("Edit"));
   gtk_box_pack_start_defaults(GTK_BOX(hbox), context->but_edit);
   gtk_signal_connect(GTK_OBJECT(context->but_edit), "clicked",
 		     GTK_SIGNAL_FUNC(on_location_edit), context);
@@ -492,7 +492,7 @@ static GtkWidget *location_widget(location_context_t *context) {
 void cb_menu_settings(GtkWidget *window, gpointer data) {
   appdata_t *appdata = (appdata_t *)data;
   GtkWidget *table, *label, *hbox, *notebook;
-  GtkWidget *cbox_imperial, *cbox_load_images;
+  GtkWidget *cbox_imperial;
   settings_dialog_state_t hstate;
 
   GtkWidget *dialog = gtk_dialog_new_with_buttons(_("Settings"),
@@ -548,13 +548,6 @@ void cb_menu_settings(GtkWidget *window, gpointer data) {
 		   cbox_imperial, 0, 2, 0, 1, GTK_FILL, 0, 2, 0);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(cbox_imperial), 
 			       appdata->imperial);
-  cbox_load_images = gtk_check_button_new_with_label(
-                   _("Load images"));
-  gtk_table_attach(GTK_TABLE(table),
-		   cbox_load_images, 0, 2, 1, 2, GTK_FILL, 0, 2, 0);
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(cbox_load_images), 
-			       appdata->load_images);
-
   gtk_notebook_append_page(GTK_NOTEBOOK(notebook), table, 
 			   gtk_label_new(_("Misc")));
 
@@ -678,8 +671,6 @@ void cb_menu_settings(GtkWidget *window, gpointer data) {
 			    GTK_TOGGLE_BUTTON(hstate.cbox_gps));
     appdata->imperial = gtk_toggle_button_get_active(
 			    GTK_TOGGLE_BUTTON(cbox_imperial));
-    appdata->load_images = gtk_toggle_button_get_active(
-			    GTK_TOGGLE_BUTTON(cbox_load_images));
 
     appdata->compass_damping = 0.5 + gtk_range_get_value(GTK_RANGE(scale));
 
